Module date_parser

Module date_parser 

Natural language date parsing

Parses dates from both natural language (e.g., “tomorrow”, “next friday”) and strict format (YYYY-MM-DD).

Functions

parse_date
Parses a date from either natural language or YYYY-MM-DD format.
parse_date_not_in_past
Parses a date and rejects values that fall in the past.