Natural language date parsing
Parses dates from both natural language (e.g., “tomorrow”, “next friday”) and strict format (YYYY-MM-DD).
Functions
- parse_
date - Parses a date from either natural language or YYYY-MM-DD format.
- parse_
date_ not_ in_ past - Parses a date and rejects values that fall in the past.