pub struct JsonStorage { /* private fields */ }Expand description
JSON file-based storage implementation
Implementations
Sourceimpl JsonStorage
impl JsonStorage
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Creates a new JsonStorage pointing to the default OS data directory.
The data directory is created automatically if it does not exist.
Errors
Returns an error if the OS data directory cannot be determined or if the directory cannot be created.